import pandas as pd
import pytest
from idscrub import IDScrub
from pandas.testing import assert_frame_equal


def test_huggingface():
    scrub = IDScrub(texts=["Our names are Hamish McDonald, L. Salah, and Elena Suárez."])
    scrubbed = scrub.huggingface_entities()
    assert scrubbed == ["Our names are [PERSON], [PERSON], and [PERSON]."]


def test_huggingface_error():
    scrub = IDScrub(texts=["Our names are Hamish McDonald, L. Salah, and Elena Suárez."])

    with pytest.raises(OSError):
        scrub.huggingface_entities(hf_model_path="not_a_path")


def test_huggingface_empty():
    scrub = IDScrub([" ", "John Smith", ""])
    scrubbed = scrub.huggingface_entities()

    assert scrubbed == [" ", "[PERSON]", ""]
    assert_frame_equal(scrub.get_scrubbed_data(), pd.DataFrame({"text_id": 2, "person": [["John Smith"]]}))



import pandas as pd
from pandas.testing import assert_frame_equal


# Note: These tests will fail if the kernel has not been restarted since the SpaCy model was downloaded.
def test_chain(scrub_object):
    scrub_object.uk_phone_numbers()
    scrub_object.uk_postcodes()
    scrubbed = scrub_object.spacy_entities()

    assert scrubbed == [
        "Our names are [PERSON], [PERSON], and [PERSON].",
        "My number is [PHONENO] and I live at [POSTCODE].",
    ]


def test_chain_order(scrub_object):
    scrubbed = scrub_object.uk_phone_numbers()

    assert scrubbed == [
        "Our names are Hamish McDonald, L. Salah, and Elena Suárez.",
        "My number is [PHONENO] and I live at AA11 1AA.",
    ]

    assert scrub_object.get_scrubbed_data()["uk_phone_number"].to_list() == [["+441111111111"]]
    assert "uk_postcode" not in scrub_object.get_scrubbed_data().columns

    scrubbed = scrub_object.uk_postcodes()

    assert scrubbed == [
        "Our names are Hamish McDonald, L. Salah, and Elena Suárez.",
        "My number is [PHONENO] and I live at [POSTCODE].",
    ]
    assert scrub_object.get_scrubbed_data()["uk_phone_number"].to_list() == [["+441111111111"]]
    assert scrub_object.get_scrubbed_data()["uk_postcode"].to_list() == [["AA11 1AA"]]


def test_get_scrubbed_data_chain(scrub_object):
    scrub_object.uk_phone_numbers()
    scrub_object.uk_postcodes()
    scrub_object.spacy_entities()

    df = scrub_object.get_scrubbed_data()

    expected_df = pd.DataFrame(
        {
            "text_id": {0: 1, 1: 2},
            "uk_phone_number": {0: None, 1: ["+441111111111"]},
            "uk_postcode": {0: None, 1: ["AA11 1AA"]},
            "person": {0: ["Hamish McDonald", "L. Salah", "Elena Suárez"], 1: None},
        }
    )

    assert_frame_equal(df, expected_df)



import os
from pathlib import Path

PROJECT_DIR = Path(__file__).resolve().parents[1]

DOWNLOAD_DIR = Path.cwd()

DATA_HOME = os.path.join(PROJECT_DIR, "data")

NOTEBOOKS_HOME = os.path.join(PROJECT_DIR, "notebooks")



from idscrub import IDScrub


def test_google_phone_numbers_gb():
    scrub = IDScrub(texts=["My phone number is +441234567891! My old phone number is 01475 123456."])
    scrubbed = scrub.google_phone_numbers(region="GB")
    assert scrubbed == ["My phone number is [PHONENO]! My old phone number is [PHONENO]."]


def test_google_phone_numbers_us():
    scrub = IDScrub(texts=["My US phone number is +1-718-222-2222! My old phone number is 12124567890."])
    scrubbed = scrub.google_phone_numbers(region="US")
    assert scrubbed == ["My US phone number is [PHONENO]! My old phone number is [PHONENO]."]



import pandas as pd
import pytest
from idscrub import IDScrub
from pandas.testing import assert_frame_equal


# Note: These tests will fail if the kernel has not been restarted since the SpaCy model was downloaded.
def test_dataframe_outputs():
    df = pd.DataFrame(
        {
            "ID": [1, 2],
            "Pride and Prejudice": [
                "Mr. Darcy walked off; and Elizabeth remained with no very cordial feelings toward him.",
                "Mr. Bennet was so odd a mixture of quick parts, sarcastic humour, reserve, and caprice.",
            ],
            "Fake book": [
                "The letter to freddie-mercury@queen.com was stamped with SW1A 2AA.",
                "She forwarded the memo from Mick Jagger and David Bowie to her chief of staff, noting the postcode SW1A 2WH.",
            ],
        }
    )

    scrubbed_df, scrubbed_data = IDScrub.dataframe(df=df, id_col="ID", scrub_methods=["all"])

    expected_scrubbed_df = pd.DataFrame(
        {
            "ID": [1, 2],
            "Pride and Prejudice": [
                "[TITLE]. [PERSON] walked off; and [PERSON] remained with no very cordial feelings toward him.",
                "[TITLE]. [PERSON] was so odd a mixture of quick parts, sarcastic humour, reserve, and caprice.",
            ],
            "Fake book": [
                "The letter to [EMAIL_ADDRESS] was stamped with [POSTCODE].",
                "She forwarded the memo from [PERSON] and [PERSON] to her chief of staff, noting the postcode [POSTCODE].",
            ],
        }
    )

    expected_scrubbed_data = pd.DataFrame(
        {
            "ID": [1, 2, 1, 2],
            "column": ["Pride and Prejudice", "Pride and Prejudice", "Fake book", "Fake book"],
            "person": [["Darcy", "Elizabeth"], ["Bennet"], None, ["Mick Jagger", "David Bowie"]],
            "title": [["Mr"], ["Mr"], None, None],
            "email_address": [None, None, ["freddie-mercury@queen.com"], None],
            "url": [None, None, ["queen.com"], None],
            "uk_postcode": [None, None, ["SW1A 2AA"], ["SW1A 2WH"]],
        }
    )

    assert_frame_equal(scrubbed_df, expected_scrubbed_df)
    assert_frame_equal(scrubbed_data, expected_scrubbed_data)


def test_dataframe_exclude():
    df = pd.DataFrame(
        {
            "ID": [1, 2],
            "Pride and Prejudice": [
                "Mr. Darcy walked off; and Elizabeth remained with no very cordial feelings toward him.",
                "Mr. Bennet was so odd a mixture of quick parts, sarcastic humour, reserve, and caprice.",
            ],
            "Fake book": [
                "The letter to freddie-mercury@queen.com was stamped with SW1A 2AA.",
                "She forwarded the memo from Mick Jagger and David Bowie to her chief of staff, noting the postcode SW1A 2WH.",
            ],
        }
    )

    scrubbed_df, scrubbed_data = IDScrub.dataframe(
        df=df, id_col="ID", exclude_cols=["Fake book"], scrub_methods=["all"]
    )

    expected_scrubbed_df = pd.DataFrame(
        {
            "ID": [1, 2],
            "Pride and Prejudice": [
                "[TITLE]. [PERSON] walked off; and [PERSON] remained with no very cordial feelings toward him.",
                "[TITLE]. [PERSON] was so odd a mixture of quick parts, sarcastic humour, reserve, and caprice.",
            ],
            "Fake book": [
                "The letter to freddie-mercury@queen.com was stamped with SW1A 2AA.",
                "She forwarded the memo from Mick Jagger and David Bowie to her chief of staff, noting the postcode SW1A 2WH.",
            ],
        }
    )

    expected_scrubbed_data = pd.DataFrame(
        {
            "ID": [1, 2],
            "column": ["Pride and Prejudice", "Pride and Prejudice"],
            "person": [["Darcy", "Elizabeth"], ["Bennet"]],
            "title": [["Mr"], ["Mr"]],
        }
    )

    assert_frame_equal(scrubbed_df, expected_scrubbed_df)
    assert_frame_equal(scrubbed_data, expected_scrubbed_data)


def test_dataframe_scrub_methods():
    df = pd.DataFrame(
        {
            "ID": [1, 2],
            "Pride and Prejudice": [
                "Mr. Darcy walked off; and Elizabeth remained with no very cordial feelings toward him.",
                "Mr. Bennet was so odd a mixture of quick parts, sarcastic humour, reserve, and caprice.",
            ],
            "Fake book": [
                "The letter to freddie-mercury@queen.com was stamped with SW1A 2AA.",
                "She forwarded the memo from Mick Jagger and David Bowie to her chief of staff, noting the postcode SW1A 2WH.",
            ],
        }
    )

    scrubbed_df, scrubbed_data = IDScrub.dataframe(df=df, id_col="ID", scrub_methods=["titles"])

    expected_scrubbed_df = pd.DataFrame(
        {
            "ID": [1, 2],
            "Pride and Prejudice": [
                "[TITLE]. Darcy walked off; and Elizabeth remained with no very cordial feelings toward him.",
                "[TITLE]. Bennet was so odd a mixture of quick parts, sarcastic humour, reserve, and caprice.",
            ],
            "Fake book": [
                "The letter to freddie-mercury@queen.com was stamped with SW1A 2AA.",
                "She forwarded the memo from Mick Jagger and David Bowie to her chief of staff, noting the postcode SW1A 2WH.",
            ],
        }
    )

    expected_scrubbed_data = pd.DataFrame(
        {
            "ID": [1, 2],
            "column": ["Pride and Prejudice", "Pride and Prejudice"],
            "title": [["Mr"], ["Mr"]],
        }
    )

    assert_frame_equal(scrubbed_df, expected_scrubbed_df)
    assert_frame_equal(scrubbed_data, expected_scrubbed_data)


def test_dataframe_id_col():
    df = pd.DataFrame(
        {
            "ID": [1, 2],
            "Pride and Prejudice": [
                "Mr. Darcy walked off; and Elizabeth remained with no very cordial feelings toward him.",
                "Mr. Bennet was so odd a mixture of quick parts, sarcastic humour, reserve, and caprice.",
            ],
            "Fake book": [
                "The letter to freddie-mercury@queen.com was stamped with SW1A 2AA.",
                "She forwarded the memo from Mick Jagger and David Bowie to her chief of staff, noting the postcode SW1A 2WH.",
            ],
        }
    )

    with pytest.raises(AssertionError):
        IDScrub.dataframe(df=df, id_col="ID_not_present")



import pandas as pd
import pytest
from idscrub import IDScrub
from pandas.testing import assert_frame_equal


# Note: This test will fail if the kernel has not been restarted since the SpaCy model was downloaded.
def test_spacy():
    scrub = IDScrub(texts=["Our names are Hamish McDonald, L. Salah, and Elena Suárez."])
    scrubbed = scrub.spacy_entities(entities=["PERSON"], model_name="en_core_web_trf")
    assert scrubbed == ["Our names are [PERSON], [PERSON], and [PERSON]."]


def test_spacy_error():
    scrub = IDScrub(texts=["Our names are Hamish McDonald, L. Salah, and Elena Suárez."])

    with pytest.raises(ValueError):
        scrub.spacy_entities(model_name="not_a_model")


def test_spacy_empty():
    scrub = IDScrub([" ", "John Smith", ""])
    scrubbed = scrub.spacy_entities()

    assert scrubbed == [" ", "[PERSON]", ""]
    assert_frame_equal(scrub.get_scrubbed_data(), pd.DataFrame({"text_id": 2, "person": [["John Smith"]]}))


def test_spacy_map():
    scrub = IDScrub(["Our names are Hamish McDonald, L. Salah, and Elena Suárez.", "My company code is NASA."])
    scrubbed_texts = scrub.spacy_entities(
        entities=["PERSON", "ORG"], replacement_map={"PERSON": "[PHELLO]", "ORG": "[SPACE]"}
    )

    assert scrubbed_texts == ["Our names are [PHELLO], [PHELLO], and [PHELLO].", "My company code is [SPACE]."]


def test_spacy_get_data():
    scrub = IDScrub(["Our names are Hamish McDonald, L. Salah, and Elena Suárez.", "My company code is NASA."])

    scrub.spacy_entities(entities=["PERSON", "ORG"])

    df = scrub.get_scrubbed_data()

    expected_df = pd.DataFrame(
        {
            "text_id": {0: 1, 1: 2},
            "person": {0: ["Hamish McDonald", "L. Salah", "Elena Suárez"], 1: None},
            "org": {0: None, 1: ["NASA"]},
        }
    )

    assert_frame_equal(df, expected_df)
